@@ -48,10 +48,10 @@ public:
     const string CountQuery = "SELECT count(*) FROM " + m_Table;
     Result R;
 
-    R = T.Exec(CountQuery.c_str());
+    R = T.Exec(CountQuery);
     R.at(0).at(0).to(m_Results.first);
 
-    R = T.Exec((CountQuery + " WHERE year=" + ToString(BoringYear)).c_str());
+    R = T.Exec(CountQuery + " WHERE year=" + ToString(BoringYear));
     R.at(0).at(0).to(m_Results.second);
   }
 };
@@ -73,9 +73,8 @@ public:
 
   void operator()(argument_type &T)
   {
-    T.Exec(("INSERT INTO " + m_Table + " VALUES (" +
-	    ToString(BoringYear) + ", "
-	    "'yawn')").c_str());
+    T.Exec("INSERT INTO " + m_Table + " VALUES (" +
+	   ToString(BoringYear) + ", 'yawn')");
 
     throw runtime_error("Transaction deliberately aborted");
   }
@@ -110,7 +109,7 @@ int main(int argc, char *argv[])
 {
   try
   {
-    Connection C(argv[1] ? argv[1] : "");
+    Connection C(argv[1]);
 
     const string Table = ((argc > 2) ? argv[2] : "events");
 
