@@ -48,7 +48,7 @@ int main(int, char *argv[])
 {
   try
   {
-    Connection C(argv[1] ? argv[1] : "", false);
+    Connection C(argv[1], false);
 
     C.Perform(ReadTables());
   }
