@@ -51,11 +51,11 @@ int main(int, char *argv[])
   {
     const string Table = "events";
 
-    Connection C(argv[1] ? argv[1] : "", false);
+    Connection C(argv[1], false);
     Transaction T(C, "test38");
 
     // Count rows.
-    Result R( T.Exec(("SELECT count(*) FROM " + Table).c_str()) );
+    Result R( T.Exec("SELECT count(*) FROM " + Table) );
     int Rows;
     R.at(0).at(0).to(Rows);
 
